@@ -112,7 +112,7 @@ public:
      * Tries to load a library and prints warning/error messages
      * @return false, if an error occurred (except unknown XML elements)
      */
-    static bool tryLoadLibrary(Library& destination, const char* basepath, const char* filename);
+    static bool tryLoadLibrary(Library& destination, const std::string& basepath, const char* filename);
 
     /**
      * Execute a shell command and read the output from it. Returns true if command terminated successfully.
@@ -151,24 +151,20 @@ private:
      *   - installs optional platform dependent signal handling
      *
      * @param cppcheck cppcheck instance
-     * @param argc from main()
-     * @param argv from main()
      **/
-    int check_wrapper(CppCheck& cppcheck, int argc, const char* const argv[]);
+    int check_wrapper(CppCheck& cppcheck);
 
     /**
      * Starts the checking.
      *
      * @param cppcheck cppcheck instance
-     * @param argc from main()
-     * @param argv from main()
      * @return EXIT_FAILURE if arguments are invalid or no input files
      *         were found.
      *         If errors are found and --error-exitcode is used,
      *         given value is returned instead of default 0.
      *         If no errors are found, 0 is returned.
      */
-    int check_internal(CppCheck& cppcheck, int argc, const char* const argv[]);
+    int check_internal(CppCheck& cppcheck);
 
     /**
      * Pointer to current settings; set while check() is running.
