@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2021 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,46 +26,46 @@
 
 
 /**
-* @brief Printable (in-memory) report.
-* This report formats results and exposes them for printing.
-*/
+ * @brief Printable (in-memory) report.
+ * This report formats results and exposes them for printing.
+ */
 class PrintableReport : public Report {
 public:
     PrintableReport();
     virtual ~PrintableReport();
 
     /**
-    * @brief Create the report (file).
-    * @return true if succeeded, false if file could not be created.
-    */
-    virtual bool create();
+     * @brief Create the report (file).
+     * @return true if succeeded, false if file could not be created.
+     */
+    virtual bool create() override;
 
     /**
-    * @brief Write report header.
-    */
-    virtual void writeHeader();
+     * @brief Write report header.
+     */
+    virtual void writeHeader() override;
 
     /**
-    * @brief Write report footer.
-    */
-    virtual void writeFooter();
+     * @brief Write report footer.
+     */
+    virtual void writeFooter() override;
 
     /**
-    * @brief Write error to report.
-    * @param error Error data.
-    */
-    virtual void writeError(const ErrorItem &error);
+     * @brief Write error to report.
+     * @param error Error data.
+     */
+    virtual void writeError(const ErrorItem &error) override;
 
     /**
-    * @brief Returns the formatted report.
-    */
+     * @brief Returns the formatted report.
+     */
     QString getFormattedReportText() const;
 
 private:
 
     /**
-    * @brief Stores the formatted report contents.
-    */
+     * @brief Stores the formatted report contents.
+     */
     QString mFormattedReport;
 };
 /// @}
