@@ -147,22 +147,21 @@ static bool simplifyPathWithVariables(std::string &s, std::map<std::string, std:
 
 void ImportProject::FileSettings::setIncludePaths(const std::string &basepath, const std::list<std::string> &in, std::map<std::string, std::string, cppcheck::stricmp> &variables)
 {
-    std::list<std::string> listInc;
-    // only parse each includePath once - so remove duplicates
-    std::list<std::string> uniqueIncludePaths = in;
-    uniqueIncludePaths.sort();
-    uniqueIncludePaths.unique();
-
-    for (const std::string &it : uniqueIncludePaths) {
-        if (it.empty())
+    std::set<std::string> found;
+    const std::list<std::string> copyIn(in);
+    includePaths.clear();
+    for (const std::string &ipath : copyIn) {
+        if (ipath.empty())
             continue;
-        if (it.compare(0,2,"%(")==0)
+        if (ipath.compare(0,2,"%(")==0)
+            continue;
+        std::string s(Path::fromNativeSeparators(ipath));
+        if (!found.insert(s).second)
             continue;
-        std::string s(Path::fromNativeSeparators(it));
         if (s[0] == '/' || (s.size() > 1U && s.compare(1,2,":/") == 0)) {
             if (!endsWith(s,'/'))
                 s += '/';
-            listInc.push_back(s);
+            includePaths.push_back(s);
             continue;
         }
 
@@ -177,9 +176,8 @@ void ImportProject::FileSettings::setIncludePaths(const std::string &basepath, c
         }
         if (s.empty())
             continue;
-        listInc.push_back(s + '/');
+        includePaths.push_back(s + '/');
     }
-    includePaths.swap(listInc);
 }
 
 ImportProject::Type ImportProject::import(const std::string &filename, Settings *settings)
@@ -409,28 +407,38 @@ bool ImportProject::importCompileCommands(std::istream &istr)
 
         const std::string directory = dirpath;
 
-        std::ostringstream comm;
-        if (obj.find("arguments") != obj.end()) {
+        std::string command;
+        if (obj.count("arguments")) {
             if (obj["arguments"].is<picojson::array>()) {
                 for (const picojson::value& arg : obj["arguments"].get<picojson::array>()) {
                     if (arg.is<std::string>()) {
-                        comm << arg.get<std::string>() << " ";
+                        std::string str = arg.get<std::string>();
+                        if (str.find(" ") != std::string::npos)
+                            str = "\"" + str + "\"";
+                        command += str + " ";
                     }
                 }
             } else {
                 printError("'arguments' field in compilation database entry is not a JSON array");
                 return false;
             }
-        } else if (obj.find("command") != obj.end()) {
+        } else if (obj.count("command")) {
             if (obj["command"].is<std::string>()) {
-                comm << obj["command"].get<std::string>();
+                command = obj["command"].get<std::string>();
+            } else {
+                printError("'command' field in compilation database entry is not a string");
+                return false;
             }
         } else {
             printError("no 'arguments' or 'command' field found in compilation database entry");
             return false;
         }
 
-        const std::string command = comm.str();
+        if (!obj.count("file") || !obj["file"].is<std::string>()) {
+            printError("skip compilation database entry because it does not have a proper 'file' field");
+            continue;
+        }
+
         const std::string file = Path::fromNativeSeparators(obj["file"].get<std::string>());
 
         // Accept file?
@@ -466,15 +474,17 @@ bool ImportProject::importSln(std::istream &istr, const std::string &path, const
 {
     std::string line;
 
-    // skip magic word
     if (!std::getline(istr,line)) {
         printError("Visual Studio solution file is empty");
         return false;
     }
 
-    if (!std::getline(istr, line) || line.find("Microsoft Visual Studio Solution File") != 0) {
-        printError("Visual Studio solution file header not found");
-        return false;
+    if (line.find("Microsoft Visual Studio Solution File") != 0) {
+        // Skip BOM
+        if (!std::getline(istr, line) || line.find("Microsoft Visual Studio Solution File") != 0) {
+            printError("Visual Studio solution file header not found");
+            return false;
+        }
     }
 
     std::map<std::string,std::string,cppcheck::stricmp> variables;
