@@ -76,9 +76,9 @@ Settings::Settings()
     certainty.setEnabled(Certainty::normal, true);
 }
 
-void Settings::loadCppcheckCfg(const std::string &executable)
+void Settings::loadCppcheckCfg()
 {
-    std::string fileName = Path::getPathFromFilename(executable) + "cppcheck.cfg";
+    std::string fileName = Path::getPathFromFilename(exename) + "cppcheck.cfg";
 #ifdef FILESDIR
     if (Path::fileExists(FILESDIR "/cppcheck.cfg"))
         fileName = FILESDIR "/cppcheck.cfg";
@@ -92,6 +92,10 @@ void Settings::loadCppcheckCfg(const std::string &executable)
     if (!picojson::get_last_error().empty())
         return;
     picojson::object obj = json.get<picojson::object>();
+    if (obj.count("productName") && obj["productName"].is<std::string>())
+        cppcheckCfgProductName = obj["productName"].get<std::string>();
+    if (obj.count("about") && obj["about"].is<std::string>())
+        cppcheckCfgAbout = obj["about"].get<std::string>();
     if (obj.count("addons") && obj["addons"].is<picojson::array>()) {
         for (const picojson::value &v : obj["addons"].get<picojson::array>()) {
             const std::string &s = v.get<std::string>();
